# as.folder <- function(x, ..., groups = NULL)
as.folder <- function(x, ...)
    UseMethod("as.folder")

#as.folder.default <- function(x, ..., groups = NULL) {        
#  # Change a data frame x into an object of class 'folder'.
#  
#  return(as.folder(x, ..., groups = NULL))
#}
